var mFileUploader = null;
var mLocationObject = LocationClass.createNew();
var mCategoryList = null;
var mCategoryIndex = -1;
var mPostId = null;
var mPost = null;
var mUser = null;

var mModalID = null;
var mChoseImageList = null;
var mUploadingImageIndex = null;

function openModal(modalID) {
    mModalID = modalID;
    $(mModalID).show();
    showLayer();
}

function closeModal() {
    if (mModalID == null) {
        return;
    }
    $(mModalID).hide();
    hideLayer();

    mModalID = null;
}

function initPage() {
    mPostId = getCache(CONST_CACHE_POST_ID);
    removeCache(CONST_CACHE_POST_ID);
    mUser = getUser();
}

function enableSubmitButton() {
    $('#submitButton').removeClass('btn-secondary').addClass('btn-default').css('background-color', '#EE5546');
    $('#submitButton').click(postInformation);
}

function initPostInfo(data) {
    mPost = getPostInfo(data);
    appendUserId(mPost);
}

function getPostInfo(json) {
    return {
        id: json.id,
        category_id: json.category_id,
        imgs: json.imgs,
        title: json.title,
        desc: json.desc,
        contact_name: json.contact_name,
        contact_phone: json.contact_phone,
        location: json.location
    };
}

function bindPage() {
	bindData();
}

function bindData() {
    mFileUploader = FileUploader.createNew();

    bindCategoryListApi();
}

function bindCategoryListApi() {
    jAjaxGet('/public/config', null, function (json) {
        mCategoryList = json.post_categories;
        bindCategoryList();
        bindPostInfoApi();
    })
}

function bindCategoryList() {
    var html = getCategoryListHtml();
    $('#categoryList').html(html);
}

function getCategoryListHtml() {
    var html = '';
    $(mCategoryList).each(function (index, item) {
        html += getCategoryItemHtml(index, item);
    });
    return html;
}

function getCategoryItemHtml(index, item) {
    var html = '<div class="border-top p-2" onclick="chooseCategory(' + index + ');">' + item.label + '</div>';
    return html;
}

function chooseCategory(index) {
    mCategoryIndex = index;
    bindCategoryItem(index);
}

function bindCategoryItem(index) {
    $('#carCategory').removeClass('t-gra');
    $('#carCategory').html(mCategoryList[index].label);

    hidePage('#categoryListPage');
    hideLayer();
}

function bindPostInfoApi() {
    var data = {
        id: mPostId
    };
    jAjaxGet('/post/detail', data, function (json) {
        initPostInfo(json)
        bindPostInfo();

        enableSubmitButton();
    })
}

function bindPostInfo() {
    bindCategory(mPost.category_id);
    $('#title').val(mPost.title);
    $('#description').val(mPost.desc);
    $('#publisher').val(mPost.contact_name);
    $('#phone').val(mPost.contact_phone);
    bindCarPhotoList();
    if (mPost.location) {
        $('#formattedAddress').html('*车源的实际位置：' + mPost.location.formattedAddress);
    }
}

function bindCategory(categoryId) {
    for (var i = 0; i < mCategoryList.length; i++) {
        var category = mCategoryList[i];
        if (category.key == categoryId) {
            mCategoryIndex = i;
            $('#carCategory').html(category.label);
        }
    }
}

function takePhoto() {
    closeModal();

    if (isH5NotSupported()) {
        return;
    }

    uexCamera.open(0, 50, function (imgPath) {
        mFileUploader.uploadImage(mUser.token, CONST_UPLOAD_IMAGE_DIR_SHOPITEMS, imgPath, function (uploadedUrl) {
            mPost.imgs.push(uploadedUrl);
            bindCarPhotoList();
        });
    })
}

function chooseImage() {
    closeModal();

    if (isH5NotSupported()) {
        return;
    }

    var max = CONFIG_MAX_POST_PHOTOS - mPost.imgs.length;
    if (max <= 0) {
        showToast('最多' + CONFIG_MAX_POST_PHOTOS + '张照片');
        return;
    }

    var param={
        min:1,
        max:max,
        quality:0.4, //压缩质量
        style:1
    }
    uexImage.openPicker(param, function (error, info) {
        if (error == -1) {
            //cancelled
        } else if (error == 0) {
            mChoseImageList = info.data;
            mUploadingImageIndex = 0;

            uploadChoseImageList();
        } else {
            //error
        }
    })
}

function uploadChoseImageList() {
    startLoading('图片上传中');
    uploadChoseImage();
}

function uploadChoseImage() {
    var imgPath = mChoseImageList[mUploadingImageIndex];
    mFileUploader.uploadImage(mUser.token, CONST_UPLOAD_IMAGE_DIR_SHOPITEMS, imgPath, function (uploadedUrl) {
        mUploadingImageIndex++;

        mPost.imgs.push(uploadedUrl);
        if (mUploadingImageIndex == mChoseImageList.length) {
            finishLoading();
            bindCarPhotoList();
        } else {
            uploadChoseImage();
        }
    });
}

function bindCarPhotoList() {
    try {
        var html = '<div class="bg-white pb-2 px-2" style="width:100%;">';
        html += '<div class="mb-2">*上传车辆照片：</div>';
        $(mPost.imgs).each(function (index, item) {
            html += getCarPhotoHtml(index, item);
        });
        html += '<img src="img/take-photo.png" style="width:4rem;height:4rem;" onclick="preparePhotos();" />';
        html += '</div>';
        $('#carPhotoList').html(html);
    } catch (err) {
        jLog(err);
    }    
}

function locateNow() {
    mLocationObject.bindCurrentLocation(function (json) {
        jLog(json)
        if (json == null) {
            showToast('请开启定位权限');
        } else {
            mPost.location = json;
            $('#formattedAddress').html('*车源的实际位置：' + mPost.location.formattedAddress);
        }
    })
}

function getCarPhotoHtml(index, item) {
    //return '<img src="' + item + '" style="width:4rem;height:4rem;" class="mr-1" />';
    var html = '<div style="position:relative;float:left;" class="mr-2">';
    html += '<img src="' + item + '" style="width:4rem;height:4rem;" class="mr-2" />';
    html += '<span class="alarm" onclick="removePhoto(' + index + ');">-</span>';
    html += '</div>';
    return html;
}

function removePhoto(index) {
    mPost.imgs.splice(index, 1);
    bindCarPhotoList();
}

function postInformation() {
    mPost.category_id = (mCategoryIndex == -1) ? null : mCategoryList[mCategoryIndex].key;
    mPost.title = $.trim($('#title').val());
    mPost.desc = $.trim($('#description').val());
    mPost.contact_name = $.trim($('#publisher').val());
    mPost.contact_phone = $.trim($('#phone').val());

    var errMsg = getPostErrorMsg();
    if (errMsg != null) {
        showToast(errMsg);
        return;
    }
    jLog(mPost)
    jAjaxPostJsonContentType('/post/save', mPost, function (json) {
        jLog(json)
        jLog('ready to close')
        setTimeout(goBack, CONFIG_TOAST_DURATION_MILLISECONDS);
    })
}

function getPostErrorMsg() {
    if (mPost.category_id == null) {
        return '请选择分类板块';
    }
    if (mPost.title == '') {
        return '请输入标题';
    }
    if (mPost.desc == '') {
        return '请输入描述';
    }
    if (mPost.contact_name == '') {
        return '请输入您的昵称';
    }
    if (mPost.contact_phone == '') {
        return '请输入您的手机号';
    }
    if (isContactNumber(mPost.contact_phone) == false) {
        return '手机号输入无效，请检查';
    }
    if (mPost.imgs.length == 0) {
        return '请上传至少一张照片';
    }
    if (mPost.location == null) {
        return '请定位您的位置';
    }
    return null;
}

function showCategoryListPage() {
    openModal('#categoryListPage');
}

function preparePhotos() {
    if (mFileUploader == null) {
        return null;
    }
    if (mPost.imgs.length >= CONFIG_MAX_POST_PHOTOS) {
        showToast('最多' + CONFIG_MAX_POST_PHOTOS + '张照片');
        return;
    }
    openModal('#chooseImageOrPhotoPage');
}
