var mImagePath = null;
var mFileUploader = null;
var mImageList = [null, null];
var mImageIndex = -1;
var mUser = null;
var mIsLoading = false;
var mShop = null;
var mLocationObject = LocationClass.createNew();
var mLocation = null;
var mIsEditMode = false;
var mModalID = null;

function initPage() {
    mUser = getUser();
}

function bindPage() {
	bindData();
}

function bindData() {
    bindImageUploader();
    bindShopInfoApi();
}

function bindImageUploader() {
    if (isApp()) {
        mFileUploader = FileUploader.createNew();
    }
}

function bindShopInfoApi() {
    var data = {
        token: mUser.token
    };
    jAjaxGet('/user/shopInfo', data, function (json) {
        mShop = json.shop;
        bindShopInfo(json);
    })
}

function bindShopInfo() {
    if (mShop) {
        var approveStatus = getApproveStatusName(mShop.review_status);
        $('#approveStatus').html(approveStatus);
        $('#name').val(mShop.name);
        $('#phone').val(mShop.phone);
        $('#wechatCode').val(mShop.wechat);
        $('#description').val(mShop.desc);
        $('#storeImage').css('background-image', 'url(' + mShop.cover + ')');
        $('#license').css('background-image', 'url(' + mShop.license + ')');

        mLocation = JSON.parse(mShop.location);
        $('#address').val(mLocation.formattedAddress);
        $('#addressRow').removeClass('d-none');

        mImageList[0] = mShop.cover;
        mImageList[1] = mShop.license;
    }
}

function showPhotoPage(index) {
    if (mIsEditMode == false) {
        return;
    }
    if (mIsLoading) {
        return;
    }
    mImageIndex = index;
    openModal('#photoPage');
}

function openModal(modalID) {
    mModalID = modalID;
    $(mModalID).show();
    showLayer();
}

function updateStore() {
    var name = $.trim($('#name').val());
    var phone = $.trim($('#phone').val());
    var wechatCode = $.trim($('#wechatCode').val());
    var description = $.trim($('#description').val());

    var errorMsg = getPostErrorMsg(name, phone, wechatCode, description);
    if (errorMsg != null) {
        showToast(errorMsg);
        return;
    }

    var data = {
        name: name,
        desc: description,
        wechat: wechatCode,
        cover: mImageList[0],
        license: mImageList[1],
        phone: phone,
        location: mLocation
    };
    appendUserId(data);
    jAjaxPostJsonContentType('/shop/save', data, function (json) {
        showToast('数据已保存');
    });
}

function getPostErrorMsg(name, phone, wechatCode, description) {
    if (mImageList[0] == null) {
        return '请上传封面照片';
    }
    if (name == '') {
        return '请输入车商名称';
    }
    if (phone == '') {
        return '请输入联系方式';
    }
    if (mImageList[1] == null) {
        return '请上传营业执照';
    }
    if (mLocation == null) {
        return '请定位您的位置';
    }
    return null;
}

function enableEdit() {
    if (mIsEditMode) {
        $('#name').attr('readonly', 'readonly');
        $('#phone').attr('readonly', 'readonly');
        $('#wechatCode').attr('readonly', 'readonly');
        $('#address').attr('readonly', 'readonly');
        $('#description').attr('readonly', 'readonly');
        showLocationIcon(false);

        $('#editButton').html('编辑');
        showSaveButton(false);
    } else {
        $('#name').removeAttr('readonly');
        $('#phone').removeAttr('readonly');
        $('#wechatCode').removeAttr('readonly');
        $('#address').removeAttr('readonly');
        $('#description').removeAttr('readonly');
        showLocationIcon(true);

        $('#editButton').html('取消编辑');
        showSaveButton(true);

        if (mLocation == null) {
            mLocationObject.bindCurrentLocation(function (json) {
                mLocation = json;
                $('#address').val(mLocation.formattedAddress);
                $('#addressRow').removeClass('d-none');
            })
        }
    }
    mIsEditMode = !mIsEditMode;
}

function showSaveButton(show) {
    var html = '';
    if (show) {
        html = '<span class="border rounded py-1 px-2" onclick="updateStore();">';
        html += '<i class="fas fa-save"></i> <span class="small">保存</span>';
        html += '</span>';
    }
    $('#btnUpdate').html(html)
}

function showLocationIcon(show) {
    if (show) {
        $('#dvLocation').show();
    } else {
        $('#dvLocation').hide();
    }
}

function closeModal() {
    $(mModalID).hide();
    hideLayer();
}

function takePhoto() {
    closeModal();

    uexCamera.open(0, 50, function (imgPath) {
        mImagePath = imgPath;
        var dir = (mImageIndex == 0) ? CONST_UPLOAD_IMAGE_DIR_SHOPS : CONST_UPLOAD_IMAGE_DIR_LICENSES;
        mFileUploader.uploadImage(mUser.token, dir, imgPath, function (uploadedUrl) {
            mImageList[mImageIndex] = uploadedUrl;
            var url = 'url(' + uploadedUrl + ')';
            if (mImageIndex == 0) {
                $('#storeImage').css('background-image', url);
            } else {
                $('#license').css('background-image', url);
            }
            mIsLoading = false;
        });
    });
}

function chooseImage() {
    closeModal();
    if (isH5()) {
        return;
    }
    var param={
        min:1,
        max:1,
        quality:0.4, //压缩质量
        style:1
    }
    uexImage.openPicker(param, function (error, info) {
        if (error == -1) {
            //cancelled
        } else if (error == 0) {
            uploadPhoto(info.data[0]);
        } else {
            //error
        }
    })
}

function uploadPhoto(imgPath) {
    mImagePath = imgPath;
    var dir = (mImageIndex == 0) ? CONST_UPLOAD_IMAGE_DIR_SHOPS : CONST_UPLOAD_IMAGE_DIR_LICENSES;
    mFileUploader.uploadImage(mUser.token, dir, imgPath, function (uploadedUrl) {
        mImageList[mImageIndex] = uploadedUrl;
        var url = 'url(' + uploadedUrl + ')';
        if (mImageIndex == 0) {
            $('#storeImage').css('background-image', url);
        } else {
            $('#license').css('background-image', url);
        }
        mIsLoading = false;
    });
}

function chooseMapAddress() {
    setCache(CONST_CACHE_CHOOSE_GAODE_LOCATION_WIN_NAME, 'user_store');
    openWin('choose_address');
}

function chooseGaodeAddress() {
    var location = getObjectCache(CONST_CACHE_CHOOSE_GAODE_LOCATION_OBJECT);
    mLocation = location;
    $('#address').val(mLocation.formattedAddress);
    $('#addressRow').removeClass('d-none');
}