var CityClass = {
    createNew: function (cityPageId) {
        var mCityPageId = cityPageId;
        var mCityList = null;
        var cityObject = {};

        cityObject.isInitialized = function () {
            return mCityList != null;
        }

        cityObject.getCityIdByCityName = function (cityName) {
            for(var i = 0; i < mCityList.length; i ++) {
                var city = mCityList[i];
                if (city.city_name == cityName) {
                    return city.id;
                }
            }
            return 0;
        }

        cityObject.loadCityApi = function () {
            try {
                var cacheDate = getCache(CONST_CACHE_CITY_LIST_DATE);
                var today = getDateText(new Date());
                var cityList = getObjectCache(CONST_CACHE_CITY_LIST_OBJECT);

                if ((cacheDate == today) && (cityList != null)) {
                    mCityList = cityList;
                    cityObject.bindCityPage();
                } else {
                    jAjaxGet('/public/cities', null, function (json) {
                        setCache(CONST_CACHE_CITY_LIST_DATE, today);
                        mCityList = json.list;
                        setObjectCache(CONST_CACHE_CITY_LIST_OBJECT, mCityList);

                        cityObject.bindCityPage();
                        jLog('read city from server');
                    });
                }
            } catch(err) {
                console.dir(err)
            }

        };

        cityObject.getCity = function (index) {
            return mCityList[index];
        };

        cityObject.getCityByCityId = function (cityId) {
            var city = null;
            for (var i = 0; i < mCityList.length; i++) {
                var cityObject = mCityList[i];
                if (cityObject.id == cityId) {
                    city = cityObject;
                    break;
                }
            }
            return city;
        };

        //below are private functions, that should be only invoked in this file
        cityObject.loadCityData = function () {
            var allCityHtml = '';

            var letter = 'A';
            var cityListByLetter = [];
            var cityIndexListByLetter = [];
            var hotCityList = [];
            var hotCityIndexList = [];
            var letterList = [];
            letterList.push(letter);
            $(mCityList).each(function (index, item) {
                if (item.is_hot == 1) {
                    hotCityList.push(item);
                    hotCityIndexList.push(index);
                }
                if (item.alpha == letter) {
                    cityListByLetter.push(item);
                    cityIndexListByLetter.push(index);
                } else {
                    allCityHtml += cityObject.getLetterCityListHtml(letter, cityListByLetter, cityIndexListByLetter);
                    letter = item.alpha;
                    letterList.push(letter);
                    cityListByLetter = [item];
                    cityIndexListByLetter = [index];
                }
            });
            allCityHtml += cityObject.getLetterCityListHtml(letter, cityListByLetter, cityIndexListByLetter);

            var hotCityHtml = '';
            fillArrayOneRow(hotCityList, 3);
            fillArrayOneRow(hotCityIndexList, 3);
            for(var i = 0; i < hotCityList.length; i += 3) {
                var leftCity = hotCityList[i];
                var middleCity = hotCityList[i + 1];
                var rightCity = hotCityList[i + 2];
                var leftCityIndex = hotCityIndexList[i];
                var middleCityIndex = hotCityIndexList[i + 1];
                var rightCityIndex = hotCityIndexList[i + 2];
                hotCityHtml += cityObject.getCityRowHtml(leftCity, middleCity, rightCity, leftCityIndex, middleCityIndex, rightCityIndex);
            }

            var letterHtml = '';
            for(var l = 0; l < letterList.length; l ++) {
                letterHtml += '<div class="text-center ub-f1"><a href="#letter' + letterList[l] + '" style="color:#DC4F3F;text-decoration: none;">' + letterList[l] + '</a></div>';
            }

            $('#hotCities').html(hotCityHtml);
            $('#allCities').html(allCityHtml);
            if (isIos()) {
                $('#letters').css('top', '4.5rem');
            }
            $('#letters').html(letterHtml);

        }

        cityObject.bindCityPage = function () {
            var code = '';

            code += '<div class="mt-3 small">定位城市</div>';
            code += '<div id="currentCityBlock">';
            code += cityObject.getLocateCityRowHtml(null);
            code += '</div>';

            code += '<div id="cityListBlock">';
            code += '<div class="py-1 small">热门城市</div>';
            code += '<div id="hotCities" class="mt-2"></div>';
            code += '<div id="allCities" class="mt-2"></div>';
            code += '</div>';

            var html = '<div class="contaier-fluid">';
            html += '<div class="row">';
                html += '<div class="col">' + code + '</div>';
                html += '<div class="px-2"></div>';
            html += '</div>';
            html += '</div>';

            $(mCityPageId).html(html);

            cityObject.loadCityData();
        }

        cityObject.getLetterCityListHtml = function (letter, cityList, cityIndexList) {
            if (letter == '0') {
                return '';
            }
            var html = '<div>';
            html += '<div class="cityLetter middle p-1 m-2 rounded-circle text-white"><span id="letter' + letter + '"></span>' + letter + '</div>';
            fillArrayOneRow(cityList, 3);
            for(var i = 0; i < cityList.length; i += 3) {
                var leftCity = cityList[i];
                var middleCity = cityList[i + 1];
                var rightCity = cityList[i + 2];
                var leftCityIndex = cityIndexList[i];
                var middleCityIndex = cityIndexList[i + 1];
                var rightCityIndex = cityIndexList[i + 2];
                html += cityObject.getCityRowHtml(leftCity, middleCity, rightCity, leftCityIndex, middleCityIndex, rightCityIndex);
            }
            html += '</div>';
            return html;
        }

        cityObject.isCityMatched = function (item, letter) {
            return item.city_name.indexOf(letter) != -1;
        }

        cityObject.getCityRowHtml = function (leftCity, middleCity, rightCity, leftCityIndex, middleCityIndex, rightCityIndex) {
            var html = '<div class="row">';
            html += cityObject.getCityCode(leftCity, leftCityIndex);
            html += cityObject.getCityCode(middleCity, middleCityIndex);
            html += cityObject.getCityCode(rightCity, rightCityIndex);
            html += '</div>';
            return html;
        }

        cityObject.getLocateCityRowHtml = function (city) {
            var html = '<div class="row">';
            html += cityObject.getHighlightCityCode(city);
            html += cityObject.getWholeCountryCode();
            html += cityObject.getLocateCityCode();
            html += '</div>';
            return html;
        }

        cityObject.getLocateCityFailedRowHtml = function () {
            var html = '<div class="row">';
            html += cityObject.getHighlightCityFailedCode();
            html += cityObject.getWholeCountryCode();
            html += cityObject.getLocateCityCode();
            html += '</div>';
            return html;
        }

        cityObject.locateCurrentCity = function (cityId) {
            var city = cityObject.getCityByCityId(cityId);
            var html = cityObject.getLocateCityRowHtml(city);
            $('#currentCityBlock').html(html);
        }

        cityObject.locateCurrentCityFailed = function () {
            var html = cityObject.getLocateCityFailedRowHtml();
            $('#currentCityBlock').html(html);
        }

        cityObject.getCityCode = function (city, cityIndex) {
            if (city == null) {
                return '<div class="city col border py-1 mx-2 my-1" style="visibility: hidden;"></div>';
            }
            var code = '<div class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" onclick="chooseCity(' + cityIndex + ')">';
            code += '<span>' + city.city_name + '</span>';
            code += '</div>';
            return code;
        }

        cityObject.getWholeCountryCode = function () {
            var code = '<div class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" onclick="chooseWholeCountry()">';
            code += '<span>全国</span>';
            code += '</div>';
            return code;
        }

        cityObject.getLocateCityCode = function () {
            var code = '<div class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" onclick="locateCity()">';
            code += '<span>重新定位</span>';
            code += '</div>';
            return code;
        }

        cityObject.getHighlightCityCode = function (city) {
            if (city == null) {
                return '<div class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" style="color:#E65540;background-color:#F4B7AE;"><span id="currentCityName">定位中...</span></div>';
            }
            var code = '<div id="currentCity" class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" style="color:#E65540;background-color:#F4B7AE;" onclick="chooseCityById(' + city.id + ')">';
            code += city.city_name;
            code += '</div>';
            return code;
        }

        cityObject.getHighlightCityFailedCode = function () {
            var code = '<div class="city small ellipsis text-center col border py-1 mx-2 my-1 rounded" style="color:#E65540;background-color:#F4B7AE;">';
            code += '<span>定位失败</span>';
            code += '</div>';
            return code;
        }

        cityObject.changeCurrentCity = function (cityName) {
            var cityId = this.getCityIdByCityName(cityName);
            $('#currentCity').removeAttr("onclick").attr('onclick', 'chooseCityById(' + cityId + ')').html(cityName);
            chooseCityById(cityId);
        }

        return cityObject;
    }
};
