//device, validation, dialog, date and time, math, ajax, page, cache, html code, plugins

//device
function isApp() {
    return (CONFIG_PLATFORM != 0);
}

function isH5() {
    return (CONFIG_PLATFORM == 0);
}

function isAndroid() {
    return (CONFIG_PLATFORM == 1);
}

function isIos() {
    return (CONFIG_PLATFORM == 2);
}

function isIphoneX() {
    if (isIos() == false) {
        return false;
    }
    var height = screen.height;
    var width = screen.width;
    return ((height == 812 && width == 375) || (height == 896 && width == 414));
}

//validation
function isPhoneNumber(phone) {
    return /^1[3456789]\d{9}$/.test(phone);
}

function isContactNumber(contactNumber) {
    return  /^\d+$/.test(contactNumber);
}

function isIntMessage(name, text, min, max) {
    var num = parseInt(text);
    if (isNaN(num)) {
        return name + "输入有误";
    }
    if (min !== undefined) {
        if (num < min) {
            return name + "不能小于" + min;
        }
    }
    if (max !== undefined) {
        if (num > max) {
            return name + "不能大于" + max;
        }
    }
    return null;
}

function isNumberMessage(name, text, min, max) {
    var num = parseFloat(text);
    if (isNaN(num)) {
        return name + "输入有误";
    }
    if (min !== undefined) {
        if (num < min) {
            return name + "不能小于" + min;
        }
    }
    if (max !== undefined) {
        if (num > max) {
            return name + "不能大于" + max;
        }
    }
    return null;
}

//dialog
function jAlert(val, title) {
    var msg = null;
    var type = typeof (val);
    if (title) {
        title = title + '\n' + 'type:' + type;
    } else {
        title = 'type:' + type;
    }
    switch (type) {
        case "number":
        case "boolean":
        case "string":
            msg = type + ":" + val;
            break;
        case "undefined":
            msg = "undefined";
            break;
        case "object":
            msg = type + ":" + JSON.stringify(val);
            break;
        case "function":
            msg = "function";
            break;
        default:
            msg = "unknown type:" + type;
            break;
    }
    msg = title + '\n' + msg;
	alert(msg);
}

function showToast(content, action) {
    if (isH5()) {
        showH5Toast(content, action);
    } else if (isApp()) {
        showAppToast(content);
    }
}

function showSuccessfulToast(content) {
    showToast(content, 'success');
}

function confirmDialog(msg, confirmYes, confirmNo) {
    if (isH5()) {
        confirmH5Dialog(msg, confirmYes, confirmNo);
    } else {
        confirmAppDialog(msg, confirmYes, confirmNo);
    }
}

function showAlert(content) {
    if (isH5()) {
        $.alert(content, CONFIG_APP_NAME);
    } else {
        appcan.window.alert(CONFIG_APP_NAME, content);
    }
}

function startLoading(msg) {
    if (isUndefined(msg)) {
        msg = '';
    }
    if (isH5()) {
        $.showLoading(msg);
    } else {
        uexWindow.toast(1, 5, msg, 0);
    }
}

function finishLoading() {
    if (isH5()) {
        $.hideLoading();
    } else {
        uexWindow.closeToast();
    }
}

function jLog(val, title) {
    if (CONFIG_IS_TEST == false && isApp()) {
        return;
    }
    var html = '';
    if (title) {
        html = '<span class="font-weight-bold mr-2">' + title + ':</span>';
    }

    var msg = null;
    var type = typeof (val);
    switch (type) {
        case "number":
        case "boolean":
        case "string":
            msg = type + ":" + val;
            break;
        case "undefined":
            msg = "undefined";
            break;
        case "object":
            msg = type + ":" + JSON.stringify(val);
            break;
        case "function":
            msg = "function";
            break;
        default:
            msg = "unknown type:" + type;
            break;
    }
    html += '<span class="small">' + msg + '</span>';
    html = '<div class="border" style="word-break:break-all;">' + html + '<div>';
    if (isApp()) {
        $('#logs').prepend(html);
    } else {
        console.log(msg);
    }
}

//date and time
function getDateTimeText(date, format) {
    var year = date.getFullYear();
    var month = date.getMonth() + 1;
    var day = date.getDate();
    var hour = date.getHours();
    var minute = date.getMinutes();

    var result = format ? format : CONFIG_DEFAULT_DATE_FORMAT;
    result = result.replace('yyyy', year);
    result = result.replace('MM', getDatePart('', month));
    result = result.replace('dd', getDatePart('', day));
    result = result.replace('HH', getDatePart('', hour));
    result = result.replace('mm', getDatePart('', minute));

    result = result.replace('M', month);
    result = result.replace('d', day);
    result = result.replace('H', hour);
    result = result.replace('m', minute);

    return result;
}

function getDateText(date) {
    return getDateTimeText(date, "yyyy-MM-dd");
}

function getTimeText(date) {
    return getDateTimeText(date, "HH:mm");
}

//support yyyy-MM-dd and yyyy-MM-dd HH:mm formats
function parseDate(dateTimeString, hyphenChars, removeChars) {
    var arrDateTime = dateTimeString.split(" ");
    if (hyphenChars) {
        for (var i = 0; i < hyphenChars.length; i++) {
            arrDateTime[0] = arrDateTime[0].replace(hyphenChars[i], '-');
        }
    }
    if (removeChars) {
        for (var i = 0; i < removeChars.length; i++) {
            arrDateTime[0] = arrDateTime[0].replace(removeChars[i], '');
        }
    }

    var arrDate = arrDateTime[0].split("-");
    var dateTime = new Date();
    dateTime.setFullYear(arrDate[0]);
    dateTime.setMonth(arrDate[1] - 1, arrDate[2]);

    if (arrDateTime.length == 1) {
        dateTime.setHours(0);
        dateTime.setMinutes(0);
        dateTime.setSeconds(0);
    } else {
        var arrTime = arrDateTime[1].split(":");
        dateTime.setHours(arrTime[0]);
        dateTime.setMinutes(arrTime[1]);
        if (arrTime.length >= 3) {
            dateTime.setSeconds(arrTime[2]);
        }
        else {
            dateTime.setSeconds(0);
        }
    }

    return dateTime;
}

function getDatePart(prefix, part) {
    if (part < 10) {
        return prefix + "0" + part;
    } else {
        return prefix + part;
    }
}

function getDateDiff(oldDate, newDate, datePart) {
    var diff = newDate.getTime() - oldDate.getTime();
    return getDateDiffByDatePart(diff, datePart);
}

function addDays(date, days) {
    date.setTime(date.getTime() + days * 24 * 60 * 60 * 1000);
}

//math
function isUndefined(obj) {
    return (typeof (obj) == "undefined");
}

function string2json(jsonStr) {
	if (jsonStr) {
		return eval('(' + jsonStr + ')');
	} else {
		return null;
	}
}

//ajax
function jAjaxGet(urlPart, params, successInvoke, failedInvoke, errorInvoke, hideLoadingMessage) {
    jAjax(urlPart, 'GET', params, successInvoke, failedInvoke, errorInvoke, hideLoadingMessage);
}

function jAjaxPost(urlPart, params, successInvoke, failedInvoke, errorInvoke, hideLoadingMessage) {
    jAjax(urlPart, 'POST', params, successInvoke, failedInvoke, errorInvoke, hideLoadingMessage);
}

function jAjaxPostJsonContentType(urlPart, params, successInvoke, failedInvoke, errorInvoke) {
    jAjaxJsonContentType(urlPart, 'POST', params, successInvoke, failedInvoke, errorInvoke);
}

//page
function openWin(win_name, newWinName) {
	if (isH5()) {
		var url = win_name + ".html?r=" + Math.random();
		document.location.href = url;
	} else {
	    var name = newWinName ? newWinName : win_name;
		var args = {
			name: name,
			data: win_name + ".html",
			aniId: "2",
			type: "4",
			dataType: "0",
			width: "",
			height: "",
			animDuration: "0"
		};
		appcan.window.open(args);
	}
}

function goBack() {
	if (isH5()) {
		history.go(-1);
	} else {
		appcan.window.close(0, 1);
	}
}

function goBackWithMessage(msg) {
    showSuccessfulToast(msg);
    setTimeout('goBack();', CONFIG_TOAST_DURATION_MILLISECONDS);
}

function showPage(pageId, doesHideMainPage) {
    $(pageId).addClass('ub').css('display', 'inline');
    if (doesHideMainPage) {
        $(CONST_MAIN_PAGE_ID).removeClass('ub').hide();
    }
}

function hidePage(pageId, doesShowMainPage) {
    $(pageId).removeClass('ub').css('display', 'none');
    if (doesShowMainPage) {
        $(CONST_MAIN_PAGE_ID).addClass('ub').show();
    }
}

function openWinWithCache(pageName, cacheName, cacheValue) {
    setCache(cacheName, cacheValue);
	openWin(pageName);
}

function goLogin(fromPage, fromPageFunction, goPage) {
    var pageObject = {
        fromPage: fromPage,
        fromPageFunction: fromPageFunction,
        goPage: goPage
    };
    setObjectCache(CONST_CACHE_LOGIN_OBJECT, pageObject);
    openWin('login');
}

function goPageByIndex(index, needLogin) {
    if (index != 1) {
        mSituationId = 0;
    }
    if (needLogin) {
        var user = getUser();
        if (user == null) {
            showToast('还未登录');
        } else {
            if (user.is_shop == 0) {
                //showToast('请先到我的-我的店铺完善资料');
            }
        }
    }
    showHomePage(index);
}

function showOrHideElement(elementId, visible) {
	var jqId = '#' + elementId;
    if (visible) {
        $(jqId).show();
    } else {
        $(jqId).hide();
    }
}

function getQueryString(name) {
    var result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
    if (result == null || result.length < 1) {
        return "";
    }
    return decodeURI(result[1]);
}

function goUrl(url) {
    if (isH5()) {
        document.location.href = url;
    } else {
        appcan.window.open({
            name: 'Url',
            dataType: 4,
            data: url
        });
    }
}

function showLayer() {
    $('.layer').css('display', 'block');
}

function hideLayer() {
    $('.layer').css('display', 'none');
}
//cache
function getCache(key) {
    var data = window.localStorage.getItem(key);
    if (data == null
        || isUndefined(data)
        || data == "null"
        || data == "undefined") {
        data = "";
    }
    return data;
}

function setCache(key, data) {
    window.localStorage.removeItem(key);
    return window.localStorage.setItem(key, data);
}

function getObjectCache(key) {
    var data = getCache(key);
    if (data == '') {
        return null;
    } else {
        return string2json(data);
    }
}

function setObjectCache(key, obj) {
    if (obj == null) {
        removeCache(key);
    } else {
        var data = JSON.stringify(obj);
        setCache(key, data);
    }
}

function removeCache(key) {
    window.localStorage.removeItem(key);
}

function clearCaches() {
	window.localStorage.clear();
}

function getUser() {
    return getObjectCache(CONST_CACHE_USER);
}

function setUser(obj) {
    setObjectCache(CONST_CACHE_USER, obj);
}

function removeUser() {
    removeCache(CONST_CACHE_USER);
}

function isUserLogged() {
    var user = getUser();
    return (user != null);
}

//plugins

//makes the page exit only, go back is not disabled
function setMainWindow() {
    if (isApp()) {
        uexWindow.setReportKey('1', '1');
        uexWindow.setReportKey('0', '1');
        uexWindow.onKeyPressed = function (keyCode) {
            if (parseInt(keyCode, 10) === 0) {
                uexWidgetOne.exit(-1);
                return;
            }
        };
    }
}

function closePage() {
    goBack();
}

function closeOtherPage(winname) {
    if (isApp()) {
        appcan.window.evaluateScript(winname, 'appcan.window.close(5, 1000);');
    }
}

function flipClose() {
    if (isIos()) {
        var param = {
            isSupport: true
        };
        uexWindow.setIsSupportSwipeCallback(JSON.stringify(param));
        uexWindow.onSwipeRight = function () {
            appcan.window.close(-1);
        }
    }
}

function flipCloseHome(homePage) {
    if (isIos()) {
        var param = {
            isSupport: true
        };
        uexWindow.setIsSupportSwipeCallback(JSON.stringify(param));
        uexWindow.onSwipeRight = function () {
            appcan.window.evaluateScript(homePage, "appcan.window.close(-1)");
        }
    }
}

function isH5NotSupported() {
    if (isH5()) {
        showToast('H5 does not support current operation');
        return true;
    } else {
        return false;
    }
}