//This file contains private functions only, that are only invoked by common.js and site.js
function loadPage() {
    initPage();

	bindPage();
}

function getLoadingMessage(isGet) {
    return isGet ? CONFIG_API_GET_LOADING_MESSAGE : CONFIG_API_POST_LOADING_MESSAGE;
}

function getFooterHtml(pageIndex) {
    var html = '<div class="container-fluid">';
    html += '<div class="row middle" style="font-size:0.8em;">';
    html += getFooterItemHtml('"goPageByIndex(0);"', 'fas fa-home', '首页', pageIndex == 0);
    html += getFooterItemHtml('"goPageByIndex(1);"', 'fas fa-truck', '收车', pageIndex == 1);
    html += getFooterItemHtml('"goPageByIndex(2,true);"', 'far fa-edit', '发布', pageIndex == 2);
    html += getFooterItemHtml('"goPageByIndex(3,true);"', 'fas fa-car-alt', '批车', pageIndex == 3);
    html += getFooterItemHtml('"goPageByIndex(4);"', 'far fa-user', '我的', pageIndex == 4);
	html += '</div>';
	html += '</div>';
    return html;
}

function getFooterItemHtml(touchEvent, awesome, title, isActive) {
    var text = getFooterItemTemplate();
    if (isActive) {
        return text.replace("t-footer-inactive", "t-footer-active").replace("awesome", awesome).replace("title", title);
    } else {
        return text.replace("onclick", "ontouchstart=" + touchEvent).replace("awesome", awesome).replace("title", title);
    }
}

function getFooterItemTemplate() {
    var text = '<div class="col t-footer-inactive text-center" onclick>';
		text += '<div class="awesome fa-2x"></div>';
		text += '<div style="font-size: 0.85rem;">title</div>';
	text += '</div>';
	return text;
}

function getApiUrl(url) {
    if (CONFIG_IS_TEST) {
        return CONFIG_API_TEST_URL + url;
    } else {
        return CONFIG_API_PRODUCTION_URL + url;
    }
}

function confirmH5Dialog(msg, confirmYes, confirmNo) {
    $.confirm(msg, function () {
        //点击确认后的回调函数
        confirmYes();
    }, function () {
        //点击取消后的回调函数
        if (confirmNo) {
            confirmNo();
        }
    });
}

function confirmAppDialog(msg, confirmYes, confirmNo) {
    appcan.window.confirm({
        title: '提示',
        content: msg,
        buttons: ['确定', '取消'],
        callback: function (err, data, dataType, optId) {
            if (data == 0) {
                confirmYes();
            } else {
                if (confirmNo) {
                    confirmNo();
                }
            }
        }
    });
}

function showH5Toast(content, action) {
    if (isUndefined(action)) {
        action = "cancel";
    }
    if (action == 'success') {
        $.toast(content);
    } else {
        $.toast(content, action);
    }
}

function showAppToast(msg) {
    uexWindow.toast({
        type: 0,
        location: 5,
        msg: msg,
        duration: CONFIG_TOAST_DURATION_MILLISECONDS
    });
}

function getDateDiffByDatePart(diff, datePart) {
    switch (datePart.toLowerCase()) {
        case 'd':
            return diff / (1000 * 60 * 60 * 24.0);
        case 'h':
            return diff / (1000 * 60 * 60.0);
        case 'mi':
            return diff / (1000 * 60.0);
        case 's':
            return diff / 1000.0;
        case 'ms':
            return diff;
        case 'm':
            return diff / (1000 * 60 * 60 * 24.0 * 30);
        case 'y':
            return diff / (1000 * 60 * 60 * 24.0 * 365);
        default:
            return null;
    }
}

function jAjax(urlPart, type, params, successInvoke, failedInvoke, errorInvoke, hideLoadingMessage) {
    var url = getApiUrl(urlPart);
	var isGet = (type == 'GET');
    var loadingMsg = getLoadingMessage(isGet);
    if (params == null) {
        params = {};
    }
    if (!hideLoadingMessage) {
        startLoading(loadingMsg);
    }

    jQuery.support.cors = true;
    var log = {
        url: url,
        type: type,
        data: params
    };
    if (isApp()) {
        if (CONFIG_IS_DEBUG) {
            uexClipboard.copy(JSON.stringify(log));
        }
    }
    $.ajax({
        url: url,
        type: type,
        data: params,
        dataType: 'json',
        traditional: true,
        error: function (request) {
            if (!hideLoadingMessage) {
                finishLoading();
            }
            if (errorInvoke) {
                errorInvoke(request);
            }
            jLog(request)
            if (isApp()) {
                log.error = request;
                if (CONFIG_IS_DEBUG) {
                    uexClipboard.copy(JSON.stringify(log));
                }
            }
        },
        success: function (json) {
            if (isApp()) {
                log.response = json;
                if (CONFIG_IS_DEBUG) {
                    uexClipboard.copy(JSON.stringify(log));
                }
            }

            if (!hideLoadingMessage) {
                finishLoading();
            }
            if (json.code == 200) {
                if (successInvoke) {
                    if (json.msg) {
                        showSuccessfulToast(json.msg);
                    }
                    successInvoke(json.data);
                }
            } else if (json.code == 401) {
                removeCache(CONST_CACHE_USER);
                goLogin();
            } else {
                if (json.msg) {
                    jLog(json.msg)
                    showToast(json.msg);
                }
                if (failedInvoke) {
                    failedInvoke(json.code);
                }
            }
        }
    });
}

function jAjaxJsonContentType(urlPart, type, params, successInvoke, failedInvoke, errorInvoke) {
    var url = getApiUrl(urlPart);
    var isGet = (type == 'GET');
    var loadingMsg = getLoadingMessage(isGet);
    if (params == null) {
        params = {};
    }
    startLoading(loadingMsg);
    jQuery.support.cors = true;
    var log = {
        url: url,
        type: type,
        data: params
    };
    $.ajax({
        url: url,
        type: type,
        data: JSON.stringify(params),
        dataType: 'json',
        contentType: 'application/json',
        traditional: true,
        error: function (request) {
            finishLoading();
            if (errorInvoke) {
                errorInvoke(request);
            }
            if (isApp()) {
                log.error = request;
                uexClipboard.copy(JSON.stringify(log));
            }
        },
        success: function (json) {
            if (isApp()) {
                log.response = json;
                uexClipboard.copy(JSON.stringify(log));
            }

            finishLoading();
            if (json.code == 200) {
                if (successInvoke) {
                    if (json.msg) {
                        showSuccessfulToast(json.msg);
                    }
                    successInvoke(json.data);
                }
            } else if (json.code == 401) {
                removeUser();
                goLogin();
            } else {
                if (json.msg) {
                    jLog(json.msg)
                    showToast(json.msg);
                }
                if (failedInvoke) {
                    failedInvoke(json.code);
                }
            }
        }
    });
}

function getPageNameByIndex(index) {
    switch (index) {
        case 0:
            return 'homePage';
        case 1:
            return 'searchPage';
        case 2:
            return 'postPage';
        case 3:
            return 'carPage';
        case 4:
            return 'userPage';
        default:
            return null;
    }
}

function fitIphoneScreen() {
    $('.header').addClass('pt-3');


    var isX = isIphoneX();
    if (isX) {
        //是iphoneX
        //alert("是iphoneX")
        $(".emptyHeader").css("paddingTop","2rem");
        $(".footer").css('bottom', '1rem');
        $(".fxFooter").css('bottom', '1rem');
        $('.fxHeight').css('height', '4.2rem');
        $('.xrHeight').html('&nbsp').css('height', '1rem;');
        $('.fxFooter').after('<div class="bg-white" style="height:1rem;position: fixed;bottom: 0;z-index: 2010;width:100%;">&nbsp;</div>');
    } else {
        //不是iphoneX
        $(".emptyHeader").addClass('pt-3');
    }
}